#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-client-core
version:              0.18.2
visibility:           public
id:                   servant-client-core-0.18.2-2nb7DC03Vw3II4Gk0xXEBu
key:                  servant-client-core-0.18.2-2nb7DC03Vw3II4Gk0xXEBu
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    Core functionality and class for client function generation for servant APIs

description:
    This library provides backend-agnostic generation of client functions. For
    more information, see the README.

category:             Servant, Web
abi:                  c2367926188fd97b011017c8611106d2
exposed:              True
exposed-modules:
    Servant.Client.Core Servant.Client.Core.Auth
    Servant.Client.Core.BaseUrl Servant.Client.Core.BasicAuth
    Servant.Client.Core.ClientError Servant.Client.Core.HasClient
    Servant.Client.Core.Reexport Servant.Client.Core.Request
    Servant.Client.Core.Response Servant.Client.Core.RunClient
    Servant.Client.Free Servant.Client.Generic

hidden-modules:       Servant.Client.Core.Internal
import-dirs:          /usr/lib/ghc-8.10.5/site-local/servant-client-core-0.18.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/servant-client-core-0.18.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/servant-client-core-0.18.2
hs-libraries:         HSservant-client-core-0.18.2-2nb7DC03Vw3II4Gk0xXEBu
depends:
    aeson-1.5.6.0-IA546NaLWlLGqcowhw6tTs base-4.14.2.0
    base-compat-0.11.2-Eyusxyk2CrTGloLdon9bIK
    base64-bytestring-1.2.0.1-Gn2QlQL7quxDmGBEoLUsKs
    bytestring-0.10.12.0 containers-0.6.4.1 deepseq-1.4.4.0
    exceptions-0.10.4 free-5.1.7-G4cc1Y718fXDuPxii9x6Pg
    http-media-0.8.0.0-LqcSk1mG0Ue6jNPSZJ0rHq
    http-types-0.12.3-Di0Av9jbzuQGAtr7LDgLEc
    network-uri-2.6.4.1-FvgDgWAahTMJnOZjiFXR50
    safe-0.3.19-DlKvqLTtraZKItu5PR3KBM
    servant-0.18.2-8nC7BHdls2ZGH0w3L9LXip
    sop-core-0.5.0.1-DRjYElI1EPTKAV573Fpd8I template-haskell-2.16.0.0
    text-1.2.4.1 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-servant-client-core/html/servant-client-core.haddock

haddock-html:         /usr/share/doc/haskell-servant-client-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

